@@ -23,7 +23,6 @@
 #include <QRandomGenerator>
 #include <QRegularExpression>
 #include <QStringList>
-#include <kwidgetsaddons_version.h>
 
 #include "mailtransport_debug.h"
 #include <KConfig>
@@ -72,7 +71,7 @@ public:
     int defaultTransportId = -1;
     bool isMainInstance = false;
     QList<TransportJob *> walletQueue;
-    QMap<Transport*, QMetaObject::Connection> passwordConnections;
+    QMap<Transport *, QMetaObject::Connection> passwordConnections;
     TransportManager *const q;
 
     void readConfig();
@@ -244,12 +243,11 @@ bool TransportManager::showTransportCreationDialog(QWidget *parent, ShowConditio
             return true;
         }
 
-        const int response = KMessageBox::messageBox(parent,
-                                                     KMessageBox::WarningContinueCancel,
-                                                     i18n("You must create an outgoing account before sending."),
-                                                     i18n("Create Account Now?"),
-                                                     KGuiItem(i18n("Create Account Now")),
-                                                     KStandardGuiItem::cancel());
+        const int response = KMessageBox::warningContinueCancel(parent,
+                                                                i18n("You must create an outgoing account before sending."),
+                                                                i18n("Create Account Now?"),
+                                                                KGuiItem(i18n("Create Account Now")),
+                                                                KStandardGuiItem::cancel());
         if (response != KMessageBox::Continue) {
             return false;
         }
@@ -539,7 +537,7 @@ void TransportManager::loadPasswords()
         if (d->passwordConnections.contains(t)) {
             continue;
         }
-        auto conn = connect(t, &Transport::passwordLoaded, this, [&](){
+        auto conn = connect(t, &Transport::passwordLoaded, this, [&]() {
             disconnect(d->passwordConnections[t]);
             d->passwordConnections.remove(t);
             if (d->passwordConnections.count() == 0) {
@@ -562,7 +560,7 @@ void TransportManager::loadPasswordsAsync()
             if (d->passwordConnections.contains(t)) {
                 continue;
             }
-            auto conn = connect(t, &Transport::passwordLoaded, this, [&](){
+            auto conn = connect(t, &Transport::passwordLoaded, this, [&]() {
                 disconnect(d->passwordConnections[t]);
                 d->passwordConnections.remove(t);
                 if (d->passwordConnections.count() == 0) {
@@ -586,7 +584,7 @@ void TransportManagerPrivate::startQueuedJobs()
         }
     }
 
-    for (auto job: jobsToDel) {
+    for (auto job : jobsToDel) {
         walletQueue.removeAll(job);
     }
 }
@@ -629,11 +627,7 @@ void TransportManagerPrivate::migrateToWallet()
     }
 
     // ask user if he wants to migrate
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int result = KMessageBox::questionTwoActionsList(nullptr,
-#else
-    int result = KMessageBox::questionYesNoList(nullptr,
-#endif
                                                      i18n("The following mail transports store their passwords in an "
                                                           "unencrypted configuration file.\nFor security reasons, "
                                                           "please consider migrating these passwords to KWallet, the "
@@ -645,11 +639,7 @@ void TransportManagerPrivate::migrateToWallet()
                                                      KGuiItem(i18n("Migrate")),
                                                      KGuiItem(i18n("Keep")),
                                                      QStringLiteral("WalletMigrate"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (result != KMessageBox::ButtonCode::PrimaryAction) {
-#else
-    if (result != KMessageBox::Yes) {
-#endif
         return;
     }
 
